html,
body {
  min-height: 100%;
}
.humane,
.humane-original {
  position: fixed;
  -moz-transition: all 0.2s ease-out;
  -webkit-transition: all 0.2s ease-out;
  -ms-transition: all 0.2s ease-out;
  -o-transition: all 0.2s ease-out;
  transition: all 0.2s ease-out;
  z-index: 100000;
  filter: progid:DXImageTransform.Microsoft.Alpha(Opacity=100);
}
.humane,
.humane-original {
  font-family: Ubuntu, Verdana, sans-serif;
  line-height: 40px;
  font-size: 25px;
  top: 25%;
  left: 25%;
  opacity: 0;
  width: 50%;
  min-height: 40px;
  padding: 10px;
  text-align: center;
  background-color: #000;
  color: #fff;
  -webkit-border-radius: 15px;
  border-radius: 15px;
}
.humane p,
.humane-original p,
.humane ul,
.humane-original ul {
  margin: 0;
  padding: 0;
}
.humane ul,
.humane-original ul {
  list-style: none;
}
.humane.humane-original-info,
.humane-original.humane-original-info {
  background-color: #030;
}
.humane.humane-original-success,
.humane-original.humane-original-success {
  background-color: #030;
}
.humane.humane-original-error,
.humane-original.humane-original-error {
  background-color: #300;
}
.humane.humane-animate,
.humane-original.humane-original-animate {
  opacity: 0.8;
}
.humane.humane-animate:hover,
.humane-original.humane-original-animate:hover {
  opacity: 0.6;
}
.humane.humane-js-animate,
.humane-original.humane-original-js-animate {
  opacity: 0.8;
}
.humane.humane-js-animate:hover,
.humane-original.humane-original-js-animate:hover {
  opacity: 0.6;
  filter: progid:DXImageTransform.Microsoft.Alpha(Opacity=60);
}
